Crate kcr_security_istio_io

Crate kcr_security_istio_io 

This crate contains kube-rs compatible bindings for Kubernetes custom resources for the security.istio.io group. Each binding is generated with kopium, updated and released weekly.

Available Custom Resources

security.istio.io/v1

  • AuthorizationPolicy
  • PeerAuthentication
  • RequestAuthentication

security.istio.io/v1beta1

  • AuthorizationPolicy
  • PeerAuthentication
  • RequestAuthentication

Modules

v1
v1beta1