This crate contains kube-rs compatible bindings for Kubernetes custom resources for the security.istio.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
security.istio.io/v1
AuthorizationPolicyPeerAuthenticationRequestAuthentication
security.istio.io/v1beta1
AuthorizationPolicyPeerAuthenticationRequestAuthentication